[gnome-maps] transitItineraryRow: Adjust compacted threashold
- From: Marcus Lundblad <mlundblad src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-maps] transitItineraryRow: Adjust compacted threashold
- Date: Mon, 4 Nov 2019 19:41:45 +0000 (UTC)
commit 2da25bbeb1d4a407d014fa574de31da047e5f307
Author: Marcus Lundblad <ml update uu se>
Date: Mon Nov 4 20:39:30 2019 +0100
transitItineraryRow: Adjust compacted threashold
Adjust the estimated space threashold when to
start using compacted leg designations
(with just the mode icons) to avoid
ellipsization in some circumstances.
src/transitItineraryRow.js | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/transitItineraryRow.js b/src/transitItineraryRow.js
index b4b18782..239c529b 100644
--- a/src/transitItineraryRow.js
+++ b/src/transitItineraryRow.js
@@ -54,10 +54,10 @@ var TransitItineraryRow = GObject.registerClass({
*/
let useCompact = length > 2;
/* don't show the route labels if too much space is consumed,
* the constant 28 here was empiracally tested out...
*/
let estimatedSpace = this._calculateEstimatedSpace();
- let useContractedLabels = estimatedSpace > 28;
+ let useContractedLabels = estimatedSpace > 26;
this._itinerary.legs.forEach((leg, i) => {
this._summaryGrid.add(this._createLeg(leg, useCompact,
[
@@ -54,10 +54,10 @@ var TransitItineraryRow = GObject.registerClass({
let useCompact = length > 2;
/* don't show the route labels if too much space is consumed,
- * the constant 28 here was empiracally tested out...
+ * the constant 26 here was empiracally tested out...
*/
let estimatedSpace = this._calculateEstimatedSpace();
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]